# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cloudproxyd/v1/cloudproxyd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/cloudproxyd/v1/cloudproxyd.proto',
  package='github.com.metaprov.modelaapi.services.cloudproxyd.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/cloudproxyd/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGgithub.com/metaprov/modelaapi/services/cloudproxyd/v1/cloudproxyd.proto\x12\x35github.com.metaprov.modelaapi.services.cloudproxyd.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse\"\xe5\x02\n\x19VirtualBucketExistRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x06secret\x18\x03 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1aVirtualBucketExistResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\"\x8c\x03\n\x1eKeyExistInVirtualBucketRequest\x12\x0e\n\x06region\x18\x01 \x01(\t\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0b\n\x03key\x18\x03 \x01(\t\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12q\n\x06secret\x18\x05 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"0\n\x1fKeyExistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\"\x1c\n\x1a\x43loudVirtualBucketResponse\"\xf4\x02\n\x13\x46ileDownloadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x06secret\x18\x05 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x46ileDownloadResponse\"\xf0\x02\n\x11\x46ileUploadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x05 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x14\n\x12\x46ileUploadResponse\"\xe7\x02\n\x1a\x43reateVirtualBucketRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12m\n\x06secret\x18\x03 \x03(\x0b\x32].github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x1d\n\x1b\x43reateVirtualBucketResponse2\xd3\x08\n\x11\x43loudProxyService\x12\xa5\x01\n\x08\x44ownload\x12J.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest\x1aK.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadResponse\"\x00\x12\x9f\x01\n\x06Upload\x12H.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest\x1aI.github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadResponse\"\x00\x12\xca\x01\n\x17KeyExistInVirtualBucket\x12U.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest\x1aV.github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse\"\x00\x12\xbb\x01\n\x12VirtualBucketExist\x12P.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest\x1aQ.github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse\"\x00\x12\xc8\x01\n\x1d\x43reateVirtualBucketIfNotExist\x12Q.github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest\x1aR.github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketResponse\"\x00\x12\x9d\x01\n\x08Shutdown\x12\x46.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownRequest\x1aG.github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownResponse\"\x00\x42\x37Z5github.com/metaprov/modelaapi/services/cloudproxyd/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=218,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=238,
)


_VIRTUALBUCKETEXISTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=598,
)

_VIRTUALBUCKETEXISTREQUEST = _descriptor.Descriptor(
  name='VirtualBucketExistRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.secret', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VIRTUALBUCKETEXISTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=598,
)


_VIRTUALBUCKETEXISTRESPONSE = _descriptor.Descriptor(
  name='VirtualBucketExistResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exist', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse.exist', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=600,
  serialized_end=643,
)


_KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=598,
)

_KEYEXISTINVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='KeyExistInVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.region', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.bucket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=1042,
)


_KEYEXISTINVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='KeyExistInVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exist', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse.exist', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1092,
)


_CLOUDVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='CloudVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1094,
  serialized_end=1122,
)


_FILEDOWNLOADREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=598,
)

_FILEDOWNLOADREQUEST = _descriptor.Descriptor(
  name='FileDownloadRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILEDOWNLOADREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1497,
)


_FILEDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='FileDownloadResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=1521,
)


_FILEUPLOADREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=598,
)

_FILEUPLOADREQUEST = _descriptor.Descriptor(
  name='FileUploadRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILEUPLOADREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1524,
  serialized_end=1892,
)


_FILEUPLOADRESPONSE = _descriptor.Descriptor(
  name='FileUploadResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1894,
  serialized_end=1914,
)


_CREATEVIRTUALBUCKETREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=598,
)

_CREATEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.secret', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEVIRTUALBUCKETREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1917,
  serialized_end=2276,
)


_CREATEVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='CreateVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2278,
  serialized_end=2307,
)

_VIRTUALBUCKETEXISTREQUEST_SECRETENTRY.containing_type = _VIRTUALBUCKETEXISTREQUEST
_VIRTUALBUCKETEXISTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_VIRTUALBUCKETEXISTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_VIRTUALBUCKETEXISTREQUEST.fields_by_name['secret'].message_type = _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY
_KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY.containing_type = _KEYEXISTINVIRTUALBUCKETREQUEST
_KEYEXISTINVIRTUALBUCKETREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_KEYEXISTINVIRTUALBUCKETREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_KEYEXISTINVIRTUALBUCKETREQUEST.fields_by_name['secret'].message_type = _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY
_FILEDOWNLOADREQUEST_SECRETENTRY.containing_type = _FILEDOWNLOADREQUEST
_FILEDOWNLOADREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_FILEDOWNLOADREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_FILEDOWNLOADREQUEST.fields_by_name['secret'].message_type = _FILEDOWNLOADREQUEST_SECRETENTRY
_FILEUPLOADREQUEST_SECRETENTRY.containing_type = _FILEUPLOADREQUEST
_FILEUPLOADREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_FILEUPLOADREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_FILEUPLOADREQUEST.fields_by_name['secret'].message_type = _FILEUPLOADREQUEST_SECRETENTRY
_CREATEVIRTUALBUCKETREQUEST_SECRETENTRY.containing_type = _CREATEVIRTUALBUCKETREQUEST
_CREATEVIRTUALBUCKETREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATEVIRTUALBUCKETREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATEVIRTUALBUCKETREQUEST.fields_by_name['secret'].message_type = _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['VirtualBucketExistRequest'] = _VIRTUALBUCKETEXISTREQUEST
DESCRIPTOR.message_types_by_name['VirtualBucketExistResponse'] = _VIRTUALBUCKETEXISTRESPONSE
DESCRIPTOR.message_types_by_name['KeyExistInVirtualBucketRequest'] = _KEYEXISTINVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['KeyExistInVirtualBucketResponse'] = _KEYEXISTINVIRTUALBUCKETRESPONSE
DESCRIPTOR.message_types_by_name['CloudVirtualBucketResponse'] = _CLOUDVIRTUALBUCKETRESPONSE
DESCRIPTOR.message_types_by_name['FileDownloadRequest'] = _FILEDOWNLOADREQUEST
DESCRIPTOR.message_types_by_name['FileDownloadResponse'] = _FILEDOWNLOADRESPONSE
DESCRIPTOR.message_types_by_name['FileUploadRequest'] = _FILEUPLOADREQUEST
DESCRIPTOR.message_types_by_name['FileUploadResponse'] = _FILEUPLOADRESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest'] = _CREATEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualBucketResponse'] = _CREATEVIRTUALBUCKETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

VirtualBucketExistRequest = _reflection.GeneratedProtocolMessageType('VirtualBucketExistRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _VIRTUALBUCKETEXISTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _VIRTUALBUCKETEXISTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistRequest)
  })
_sym_db.RegisterMessage(VirtualBucketExistRequest)
_sym_db.RegisterMessage(VirtualBucketExistRequest.SecretEntry)

VirtualBucketExistResponse = _reflection.GeneratedProtocolMessageType('VirtualBucketExistResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALBUCKETEXISTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.VirtualBucketExistResponse)
  })
_sym_db.RegisterMessage(VirtualBucketExistResponse)

KeyExistInVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('KeyExistInVirtualBucketRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketRequest)
  })
_sym_db.RegisterMessage(KeyExistInVirtualBucketRequest)
_sym_db.RegisterMessage(KeyExistInVirtualBucketRequest.SecretEntry)

KeyExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('KeyExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _KEYEXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.KeyExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(KeyExistInVirtualBucketResponse)

CloudVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CloudVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CloudVirtualBucketResponse)

FileDownloadRequest = _reflection.GeneratedProtocolMessageType('FileDownloadRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILEDOWNLOADREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _FILEDOWNLOADREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadRequest)
  })
_sym_db.RegisterMessage(FileDownloadRequest)
_sym_db.RegisterMessage(FileDownloadRequest.SecretEntry)

FileDownloadResponse = _reflection.GeneratedProtocolMessageType('FileDownloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILEDOWNLOADRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileDownloadResponse)
  })
_sym_db.RegisterMessage(FileDownloadResponse)

FileUploadRequest = _reflection.GeneratedProtocolMessageType('FileUploadRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILEUPLOADREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _FILEUPLOADREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadRequest)
  })
_sym_db.RegisterMessage(FileUploadRequest)
_sym_db.RegisterMessage(FileUploadRequest.SecretEntry)

FileUploadResponse = _reflection.GeneratedProtocolMessageType('FileUploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _FILEUPLOADRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.FileUploadResponse)
  })
_sym_db.RegisterMessage(FileUploadResponse)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)
_sym_db.RegisterMessage(CreateVirtualBucketRequest.SecretEntry)

CreateVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cloudproxyd.v1.cloudproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cloudproxyd.v1.CreateVirtualBucketResponse)
  })
_sym_db.RegisterMessage(CreateVirtualBucketResponse)


DESCRIPTOR._options = None
_VIRTUALBUCKETEXISTREQUEST_SECRETENTRY._options = None
_KEYEXISTINVIRTUALBUCKETREQUEST_SECRETENTRY._options = None
_FILEDOWNLOADREQUEST_SECRETENTRY._options = None
_FILEUPLOADREQUEST_SECRETENTRY._options = None
_CREATEVIRTUALBUCKETREQUEST_SECRETENTRY._options = None

_CLOUDPROXYSERVICE = _descriptor.ServiceDescriptor(
  name='CloudProxyService',
  full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2310,
  serialized_end=3417,
  methods=[
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.Download',
    index=0,
    containing_service=None,
    input_type=_FILEDOWNLOADREQUEST,
    output_type=_FILEDOWNLOADRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Upload',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.Upload',
    index=1,
    containing_service=None,
    input_type=_FILEUPLOADREQUEST,
    output_type=_FILEUPLOADRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeyExistInVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.KeyExistInVirtualBucket',
    index=2,
    containing_service=None,
    input_type=_KEYEXISTINVIRTUALBUCKETREQUEST,
    output_type=_KEYEXISTINVIRTUALBUCKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VirtualBucketExist',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.VirtualBucketExist',
    index=3,
    containing_service=None,
    input_type=_VIRTUALBUCKETEXISTREQUEST,
    output_type=_VIRTUALBUCKETEXISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualBucketIfNotExist',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.CreateVirtualBucketIfNotExist',
    index=4,
    containing_service=None,
    input_type=_CREATEVIRTUALBUCKETREQUEST,
    output_type=_CREATEVIRTUALBUCKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='github.com.metaprov.modelaapi.services.cloudproxyd.v1.CloudProxyService.Shutdown',
    index=5,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLOUDPROXYSERVICE)

DESCRIPTOR.services_by_name['CloudProxyService'] = _CLOUDPROXYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cronprediction/v1/cronprediction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/cronprediction/v1/cronprediction.proto',
  package='github.com.metaprov.modelaapi.services.cronprediction.v1',
  syntax='proto3',
  serialized_options=b'Z8github.com/metaprov/modelaapi/services/cronprediction/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nMgithub.com/metaprov/modelaapi/services/cronprediction/v1/cronprediction.proto\x12\x38github.com.metaprov.modelaapi.services.cronprediction.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xde\x01\n\x1aListCronPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12p\n\x06labels\x18\x03 \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x1bListCronPredictionsResponse\x12\\\n\x05items\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPredictionList\"\x1e\n\x1c\x43reateCronPredictionResponse\"v\n\x1b\x43reateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"v\n\x1bUpdateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x1e\n\x1cUpdateCronPredictionResponse\";\n\x18GetCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x82\x01\n\x19GetCronPredictionResponse\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1b\x44\x65leteCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteCronPredictionResponse\"=\n\x1aPauseCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bPauseCronPredictionResponse\">\n\x1bResumeCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1e\n\x1cResumeCronPredictionResponse\"s\n\x18RunCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x1b\n\x19RunCronPredictionResponse2\xfc\x0e\n\x15\x43ronPredictionService\x12\xdf\x01\n\x13ListCronPredictions\x12T.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest\x1aU.github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/cronpredictions\x12\xe5\x01\n\x14\x43reateCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/cronpredictions:\x01*\x12\xe0\x01\n\x11GetCronPrediction\x12R.github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest\x1aS.github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/cronpredictions/{name}\x12\x84\x02\n\x14UpdateCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionResponse\"=\x82\xd3\xe4\x93\x02\x37\x1a\x32/v1/cronpredictions/{cronprediction.metadata.name}:\x01*\x12\xe9\x01\n\x14\x44\x65leteCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionResponse\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/cronpredictions/{name}\x12\xec\x01\n\x13PauseCronPrediction\x12T.github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest\x1aU.github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/cronpredictions/{name}:pause\x12\xf0\x01\n\x14ResumeCronPrediction\x12U.github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest\x1aV.github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/cronpredictions/{name}:resume\x12\xe0\x01\n\rRunPrediction\x12R.github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest\x1aS.github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/v1/cronpredictions/{name}:runB:Z8github.com/metaprov/modelaapi/services/cronprediction/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTCRONPREDICTIONSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=467,
)

_LISTCRONPREDICTIONSREQUEST = _descriptor.Descriptor(
  name='ListCronPredictionsRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCRONPREDICTIONSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=467,
)


_LISTCRONPREDICTIONSRESPONSE = _descriptor.Descriptor(
  name='ListCronPredictionsResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=592,
)


_CREATECRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='CreateCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=624,
)


_CREATECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='CreateCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=744,
)


_UPDATECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='UpdateCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=864,
)


_UPDATECRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='UpdateCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=896,
)


_GETCRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='GetCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=898,
  serialized_end=957,
)


_GETCRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='GetCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1090,
)


_DELETECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='DeleteCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1154,
)


_DELETECRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='DeleteCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1186,
)


_PAUSECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='PauseCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1188,
  serialized_end=1249,
)


_PAUSECRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='PauseCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1280,
)


_RESUMECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='ResumeCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1344,
)


_RESUMECRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='ResumeCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1376,
)


_RUNCRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='RunCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1493,
)


_RUNCRONPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='RunCronPredictionResponse',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1522,
)

_LISTCRONPREDICTIONSREQUEST_LABELSENTRY.containing_type = _LISTCRONPREDICTIONSREQUEST
_LISTCRONPREDICTIONSREQUEST.fields_by_name['labels'].message_type = _LISTCRONPREDICTIONSREQUEST_LABELSENTRY
_LISTCRONPREDICTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTIONLIST
_CREATECRONPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_UPDATECRONPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_GETCRONPREDICTIONRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_RUNCRONPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
DESCRIPTOR.message_types_by_name['ListCronPredictionsRequest'] = _LISTCRONPREDICTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCronPredictionsResponse'] = _LISTCRONPREDICTIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateCronPredictionResponse'] = _CREATECRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateCronPredictionRequest'] = _CREATECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronPredictionRequest'] = _UPDATECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronPredictionResponse'] = _UPDATECRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['GetCronPredictionRequest'] = _GETCRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['GetCronPredictionResponse'] = _GETCRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCronPredictionRequest'] = _DELETECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteCronPredictionResponse'] = _DELETECRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['PauseCronPredictionRequest'] = _PAUSECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['PauseCronPredictionResponse'] = _PAUSECRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['ResumeCronPredictionRequest'] = _RESUMECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['ResumeCronPredictionResponse'] = _RESUMECRONPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['RunCronPredictionRequest'] = _RUNCRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['RunCronPredictionResponse'] = _RUNCRONPREDICTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCronPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListCronPredictionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsRequest)
  })
_sym_db.RegisterMessage(ListCronPredictionsRequest)
_sym_db.RegisterMessage(ListCronPredictionsRequest.LabelsEntry)

ListCronPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListCronPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ListCronPredictionsResponse)
  })
_sym_db.RegisterMessage(ListCronPredictionsResponse)

CreateCronPredictionResponse = _reflection.GeneratedProtocolMessageType('CreateCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionResponse)
  })
_sym_db.RegisterMessage(CreateCronPredictionResponse)

CreateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('CreateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.CreateCronPredictionRequest)
  })
_sym_db.RegisterMessage(CreateCronPredictionRequest)

UpdateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionRequest)
  })
_sym_db.RegisterMessage(UpdateCronPredictionRequest)

UpdateCronPredictionResponse = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.UpdateCronPredictionResponse)
  })
_sym_db.RegisterMessage(UpdateCronPredictionResponse)

GetCronPredictionRequest = _reflection.GeneratedProtocolMessageType('GetCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionRequest)
  })
_sym_db.RegisterMessage(GetCronPredictionRequest)

GetCronPredictionResponse = _reflection.GeneratedProtocolMessageType('GetCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.GetCronPredictionResponse)
  })
_sym_db.RegisterMessage(GetCronPredictionResponse)

DeleteCronPredictionRequest = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionRequest)
  })
_sym_db.RegisterMessage(DeleteCronPredictionRequest)

DeleteCronPredictionResponse = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.DeleteCronPredictionResponse)
  })
_sym_db.RegisterMessage(DeleteCronPredictionResponse)

PauseCronPredictionRequest = _reflection.GeneratedProtocolMessageType('PauseCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionRequest)
  })
_sym_db.RegisterMessage(PauseCronPredictionRequest)

PauseCronPredictionResponse = _reflection.GeneratedProtocolMessageType('PauseCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.PauseCronPredictionResponse)
  })
_sym_db.RegisterMessage(PauseCronPredictionResponse)

ResumeCronPredictionRequest = _reflection.GeneratedProtocolMessageType('ResumeCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionRequest)
  })
_sym_db.RegisterMessage(ResumeCronPredictionRequest)

ResumeCronPredictionResponse = _reflection.GeneratedProtocolMessageType('ResumeCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.ResumeCronPredictionResponse)
  })
_sym_db.RegisterMessage(ResumeCronPredictionResponse)

RunCronPredictionRequest = _reflection.GeneratedProtocolMessageType('RunCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionRequest)
  })
_sym_db.RegisterMessage(RunCronPredictionRequest)

RunCronPredictionResponse = _reflection.GeneratedProtocolMessageType('RunCronPredictionResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONPREDICTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronprediction.v1.cronprediction_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronprediction.v1.RunCronPredictionResponse)
  })
_sym_db.RegisterMessage(RunCronPredictionResponse)


DESCRIPTOR._options = None
_LISTCRONPREDICTIONSREQUEST_LABELSENTRY._options = None

_CRONPREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='CronPredictionService',
  full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1525,
  serialized_end=3441,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListCronPredictions',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.ListCronPredictions',
    index=0,
    containing_service=None,
    input_type=_LISTCRONPREDICTIONSREQUEST,
    output_type=_LISTCRONPREDICTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/cronpredictions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.CreateCronPrediction',
    index=1,
    containing_service=None,
    input_type=_CREATECRONPREDICTIONREQUEST,
    output_type=_CREATECRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\023/v1/cronpredictions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.GetCronPrediction',
    index=2,
    containing_service=None,
    input_type=_GETCRONPREDICTIONREQUEST,
    output_type=_GETCRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/cronpredictions/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.UpdateCronPrediction',
    index=3,
    containing_service=None,
    input_type=_UPDATECRONPREDICTIONREQUEST,
    output_type=_UPDATECRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0322/v1/cronpredictions/{cronprediction.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.DeleteCronPrediction',
    index=4,
    containing_service=None,
    input_type=_DELETECRONPREDICTIONREQUEST,
    output_type=_DELETECRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\034*\032/v1/cronpredictions/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.PauseCronPrediction',
    index=5,
    containing_service=None,
    input_type=_PAUSECRONPREDICTIONREQUEST,
    output_type=_PAUSECRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\" /v1/cronpredictions/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.ResumeCronPrediction',
    index=6,
    containing_service=None,
    input_type=_RESUMECRONPREDICTIONREQUEST,
    output_type=_RESUMECRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/v1/cronpredictions/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunPrediction',
    full_name='github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService.RunPrediction',
    index=7,
    containing_service=None,
    input_type=_RUNCRONPREDICTIONREQUEST,
    output_type=_RUNCRONPREDICTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002 \"\036/v1/cronpredictions/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CRONPREDICTIONSERVICE)

DESCRIPTOR.services_by_name['CronPredictionService'] = _CRONPREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto',
  package='github.com.metaprov.modelaapi.services.reciperun.v1',
  syntax='proto3',
  serialized_options=b'Z3github.com/metaprov/modelaapi/services/reciperun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCgithub.com/metaprov/modelaapi/services/reciperun/v1/reciperun.proto\x12\x33github.com.metaprov.modelaapi.services.reciperun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xc1\x01\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x03 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x16ListRecipeRunsResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRunList\"g\n\x16\x43reateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x19\n\x17\x43reateRecipeRunResponse\"g\n\x16UpdateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x19\n\x17UpdateRecipeRunResponse\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x14GetRecipeRunResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteRecipeRunResponse2\xfa\x07\n\x10RecipeRunService\x12\xc1\x01\n\x0eListRecipeRuns\x12J.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest\x1aK.github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/reciperuns\x12\xc7\x01\n\x0f\x43reateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/reciperuns:\x01*\x12\xc2\x01\n\x0cGetRecipeRun\x12H.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest\x1aI.github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/reciperuns/{name}\x12\xe1\x01\n\x0fUpdateRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse\"3\x82\xd3\xe4\x93\x02-\x1a(/v1/reciperuns/{reciperun.metadata.name}:\x01*\x12\xae\x01\n\x0f\x44\x65leteRecipeRun\x12K.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest\x1aL.github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse\"\x00\x42\x35Z3github.com/metaprov/modelaapi/services/reciperun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTRECIPERUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=418,
)

_LISTRECIPERUNSREQUEST = _descriptor.Descriptor(
  name='ListRecipeRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRECIPERUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=418,
)


_LISTRECIPERUNSRESPONSE = _descriptor.Descriptor(
  name='ListRecipeRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=528,
)


_CREATERECIPERUNREQUEST = _descriptor.Descriptor(
  name='CreateRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=633,
)


_CREATERECIPERUNRESPONSE = _descriptor.Descriptor(
  name='CreateRecipeRunResponse',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=660,
)


_UPDATERECIPERUNREQUEST = _descriptor.Descriptor(
  name='UpdateRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=765,
)


_UPDATERECIPERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateRecipeRunResponse',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=792,
)


_GETRECIPERUNREQUEST = _descriptor.Descriptor(
  name='GetRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=848,
)


_GETRECIPERUNRESPONSE = _descriptor.Descriptor(
  name='GetRecipeRunResponse',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=965,
)


_DELETERECIPERUNREQUEST = _descriptor.Descriptor(
  name='DeleteRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1024,
)


_DELETERECIPERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteRecipeRunResponse',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1051,
)

_LISTRECIPERUNSREQUEST_LABELSENTRY.containing_type = _LISTRECIPERUNSREQUEST
_LISTRECIPERUNSREQUEST.fields_by_name['labels'].message_type = _LISTRECIPERUNSREQUEST_LABELSENTRY
_LISTRECIPERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUNLIST
_CREATERECIPERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_UPDATERECIPERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_GETRECIPERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest'] = _LISTRECIPERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse'] = _LISTRECIPERUNSRESPONSE
DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest'] = _CREATERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateRecipeRunResponse'] = _CREATERECIPERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest'] = _UPDATERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateRecipeRunResponse'] = _UPDATERECIPERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetRecipeRunRequest'] = _GETRECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['GetRecipeRunResponse'] = _GETRECIPERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest'] = _DELETERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteRecipeRunResponse'] = _DELETERECIPERUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRECIPERUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)
_sym_db.RegisterMessage(ListRecipeRunsRequest.LabelsEntry)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

CreateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('CreateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.CreateRecipeRunResponse)
  })
_sym_db.RegisterMessage(CreateRecipeRunResponse)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

UpdateRecipeRunResponse = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.UpdateRecipeRunResponse)
  })
_sym_db.RegisterMessage(UpdateRecipeRunResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

GetRecipeRunResponse = _reflection.GeneratedProtocolMessageType('GetRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.GetRecipeRunResponse)
  })
_sym_db.RegisterMessage(GetRecipeRunResponse)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

DeleteRecipeRunResponse = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.reciperun.v1.reciperun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.reciperun.v1.DeleteRecipeRunResponse)
  })
_sym_db.RegisterMessage(DeleteRecipeRunResponse)


DESCRIPTOR._options = None
_LISTRECIPERUNSREQUEST_LABELSENTRY._options = None

_RECIPERUNSERVICE = _descriptor.ServiceDescriptor(
  name='RecipeRunService',
  full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1054,
  serialized_end=2072,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListRecipeRuns',
    full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService.ListRecipeRuns',
    index=0,
    containing_service=None,
    input_type=_LISTRECIPERUNSREQUEST,
    output_type=_LISTRECIPERUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1/reciperuns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService.CreateRecipeRun',
    index=1,
    containing_service=None,
    input_type=_CREATERECIPERUNREQUEST,
    output_type=_CREATERECIPERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016/v1/reciperuns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService.GetRecipeRun',
    index=2,
    containing_service=None,
    input_type=_GETRECIPERUNREQUEST,
    output_type=_GETRECIPERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/reciperuns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService.UpdateRecipeRun',
    index=3,
    containing_service=None,
    input_type=_UPDATERECIPERUNREQUEST,
    output_type=_UPDATERECIPERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002-\032(/v1/reciperuns/{reciperun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService.DeleteRecipeRun',
    index=4,
    containing_service=None,
    input_type=_DELETERECIPERUNREQUEST,
    output_type=_DELETERECIPERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECIPERUNSERVICE)

DESCRIPTOR.services_by_name['RecipeRunService'] = _RECIPERUNSERVICE

# @@protoc_insertion_point(module_scope)
